@@ -159,81 +159,6 @@ mod tests {
         println!("{}", generate_verilog(&uut));
     }
 
-    #[test]
-    fn test_async() {
-        #[derive(LogicBlock, Clone, Default)]
-        struct Semaphore {
-            pub push: Signal<In, Bit>,
-            pub pop: Signal<In, Bit>,
-            pub clk: Signal<In, Clock>,
-            pub empty: Signal<Out, Bit>,
-            pub full: Signal<Out, Bit>,
-            will_read: Signal<Local, Bit>,
-            will_write: Signal<Local, Bit>,
-            count: DFF<Bits<4>>,
-        }
-
-        impl Logic for Semaphore {
-            #[hdl_gen]
-            fn update(&mut self) {
-                self.count.clk.next = self.clk.val();
-                self.count.d.next = self.count.q.val();
-
-                self.will_read.next = !self.empty.val() & self.pop.val();
-                self.will_write.next = !self.full.val() & self.push.val();
-
-                if self.will_read.val() & !self.will_write.val() {
-                    self.count.d.next = self.count.q.val() - 1_u32;
-                } else if self.will_write.val() & !self.will_read.val() {
-                    self.count.d.next = self.count.q.val() + 1_u32;
-                }
-
-                self.full.next = (self.count.q.val() == 15_u32).into();
-                self.empty.next = (self.count.q.val() == 0_u32).into();
-            }
-        }
-
-        let mut uut = Semaphore::default();
-        // Simulate 100 clock cycles
-        uut.clk.connect();
-        uut.pop.connect();
-        uut.push.connect();
-        uut.connect_all();
-        check_all(&uut).unwrap();
-    }
-
-    /*
-    pub async fn fifo_vector_feeder<T: Synthesizable>(
-        clock: Clock,
-        mut writer: FIFOWriterClient<T>,
-        data: Vec<T>,
-        prob_pause: f64,
-        pause_len: u64,
-    ) -> Result<(), HDLError> {
-        writer.write.set(false);
-        clock.next_negedge().await;
-        for datum in data {
-            while writer.full.get() {
-                writer.write.set(false);
-                clock.next_negedge().await;
-            }
-            if rand::thread_rng().gen::<f64>() < prob_pause {
-                writer.write.set(false);
-                clock.delay_negedge(pause_len).await;
-            }
-            writer.input.set(datum);
-            writer.write.set(true);
-            clock.next_negedge().await;
-        }
-        writer.write.set(false);
-        if writer.overflow.get() {
-            Err(HDLError::TestBenchFailed("FIFO overflowed".to_string()))
-        } else {
-            Ok(())
-        }
-    }
-     */
-
     const MHZ100: u64 = 100_000_000;
 
     #[derive(LogicBlock)]
